==> plasma-workspace-5.13.4.tar.xz: plasma-workspace-5.13.4/libtaskmanager/xwindowsystemeventbatcher.h <==
/********************************************************************
Copyright 2017  David Edmundson <davidedmundson@kde.org>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) version 3, or any
later version accepted by the membership of KDE e.V. (or its
successor approved by the membership of KDE e.V.), which shall
act as a proxy defined in Section 6 of version 3 of the license.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*********************************************************************/

#ifndef XWIDOWSYSTEMEVENTBATCHER_H
#define XWIDOWSYSTEMEVENTBATCHER_H

#include <QObject>

#include <KWindowSystem>

/*
 * Relay class for KWindowSystem events that batches updates
 */
class XWindowSystemEventBatcher : public QObject
{
    Q_OBJECT
public:
    XWindowSystemEventBatcher(QObject *parent);
Q_SIGNALS:
    void windowAdded(WId window);
    void windowRemoved(WId window);
    void windowChanged(WId window, NET::Properties properties, NET::Properties2 properties2);
protected:
    void timerEvent(QTimerEvent *event);
private:
    struct AllProps {
        NET::Properties properties = 0;
        NET::Properties2 properties2 = 0;
    };
    QHash<WId, AllProps> m_cache;
    int m_timerId = 0;
};

#endif

==> plasma-workspace_5.14.5.1.orig.tar.xz: plasma-workspace-5.14.5.1/libtaskmanager/xwindowsystemeventbatcher.h <==
/********************************************************************
Copyright 2017  David Edmundson <davidedmundson@kde.org>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) version 3, or any
later version accepted by the membership of KDE e.V. (or its
successor approved by the membership of KDE e.V.), which shall
act as a proxy defined in Section 6 of version 3 of the license.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*********************************************************************/

#ifndef XWINDOWSYSTEMEVENTBATCHER_H
#define XWINDOWSYSTEMEVENTBATCHER_H

#include <QObject>

#include <KWindowSystem>

/*
 * Relay class for KWindowSystem events that batches updates
 */
class XWindowSystemEventBatcher : public QObject
{
    Q_OBJECT
public:
    XWindowSystemEventBatcher(QObject *parent);
Q_SIGNALS:
    void windowAdded(WId window);
    void windowRemoved(WId window);
    void windowChanged(WId window, NET::Properties properties, NET::Properties2 properties2);
protected:
    void timerEvent(QTimerEvent *event);
private:
    struct AllProps {
        NET::Properties properties = 0;
        NET::Properties2 properties2 = 0;
    };
    QHash<WId, AllProps> m_cache;
    int m_timerId = 0;
};

#endif
